====
kune
====


.. image:: https://img.shields.io/pypi/v/kune.svg
        :target: https://pypi.python.org/pypi/kune

.. image:: https://img.shields.io/travis/brennan.barker/kune.svg
        :target: https://travis-ci.com/brennan.barker/kune

.. image:: https://readthedocs.org/projects/kune/badge/?version=latest
        :target: https://kune.readthedocs.io/en/latest/?badge=latest
        :alt: Documentation Status

.. image:: https://pyup.io/repos/github/BrennanBarker/kune/shield.svg
     :target: https://pyup.io/repos/github/BrennanBarker/kune/
          :alt: Updates


Host your live HTML presentations in sync across many devices.


* Free software: MIT license
* Documentation: https://kune.readthedocs.io.


Features
--------

* TODO

Credits
-------

This package was created with Cookiecutter_ and the `audreyr/cookiecutter-pypackage`_ project template.

.. _Cookiecutter: https://github.com/audreyr/cookiecutter
.. _`audreyr/cookiecutter-pypackage`: https://github.com/audreyr/cookiecutter-pypackage
